@@ -14,10 +14,10 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
 import os
-from calculate.lib.utils.files import readFile
-from collections import Mapping, deque
+from .files import readFile
+from collections import deque
+from collections.abc import Mapping
 from os import path
 import json
 from functools import wraps
@@ -178,18 +178,18 @@ class SafeVFS(VFS):
 
     def read(self, fn):
         try:
-            return super(SafeVFS, self).read(fn)
+            return super().read(fn)
         except VFSError:
             return ""
 
     def listdir(self, fn, fullpath=False):
         try:
-            return super(SafeVFS, self).listdir(fn, fullpath)
+            return super().listdir(fn, fullpath)
         except VFSError:
             return []
 
 
-class VFSObject(object):
+class VFSObject():
     def __init__(self, name):
         self.parent = None
         self.name = name
@@ -228,7 +228,7 @@ class VFSObject(object):
 
 class VFSDirectory(VFSObject, Mapping):
     def __init__(self, name, *args):
-        super(VFSDirectory, self).__init__(name)
+        super().__init__(name)
         self.children = {}
         for o in args:
             self.append(o)
@@ -296,12 +296,12 @@ class VFSDirectory(VFSObject, Mapping):
 
 class VFSRoot(VFSDirectory):
     def __init__(self, *args):
-        super(VFSRoot, self).__init__("/", *args)
+        super().__init__("/", *args)
 
     def __getitem__(self, item):
         if item == "..":
             return self
-        return super(VFSRoot, self).__getitem__(item)
+        return super().__getitem__(item)
 
     def dump(self):
         return ['/', self.name, [x.dump() for x in self]]
@@ -318,7 +318,7 @@ class VFSRoot(VFSDirectory):
 
 class VFSFile(VFSObject):
     def __init__(self, name, data=""):
-        super(VFSFile, self).__init__(name)
+        super().__init__(name)
         self.data = data
 
     def dump(self):
@@ -359,7 +359,7 @@ def detect_cyclic(f):
 
 class VFSLink(VFSObject):
     def __init__(self, name, target):
-        super(VFSLink, self).__init__(name)
+        super().__init__(name)
         self.name = name
         self._target = target
         self.deref_start = False
@@ -428,7 +428,7 @@ class VFSLink(VFSObject):
         return self.deref().__getitem__(item)
 
 
-class VFSImporter(object):
+class VFSImporter():
     """
     Имортёр файловой системы
     """
@@ -497,7 +497,7 @@ class VFSDevfsImporter(VFSImporter):
     """
 
     def __init__(self, dn="/dev", prefix="/"):
-        super(VFSDevfsImporter, self).__init__(dn, prefix)
+        super().__init__(dn, prefix)
 
     def filter_dirs(self, root, dn):
         if dn == "shm":
@@ -511,7 +511,7 @@ class VFSSysfsImporter(VFSImporter):
     """
 
     def __init__(self, dn="/sys", prefix="/"):
-        super(VFSSysfsImporter, self).__init__(dn, prefix)
+        super().__init__(dn, prefix)
 
     def import_file(self, dirobj, fn, ffn):
         if fn in ("version", "vendor", "model", "board_name",
@@ -523,7 +523,7 @@ class VFSSysfsImporter(VFSImporter):
             dirobj.append(VFSFile(fn))
 
 
-class VFSJsonKeeper(object):
+class VFSJsonKeeper():
     """
     Сохранение и загрузыка виртуальной файловой системы
     """
